@@ -861,3 +861,24 @@ int32_t SPVM__Fn__memcmp(SPVM_ENV* env, SPVM_VALUE* stack) {
   return 0;
 }
 
+int32_t SPVM__Fn__system_is_little_endian(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  int32_t system_is_little_endian = 0;
+  
+  // Copied from https://dev.to/ajipelumi/c-function-to-check-endianness-5d25
+  {
+    unsigned int i = 1;
+    char *c;
+    
+    c = (char *) &i; /* points to the first byte of the integer i */
+    if (*c == 1) /* 1st byte looks like 0x01 */
+    {
+      system_is_little_endian = 1;
+    }
+  }
+  
+  stack[0].ival = system_is_little_endian;
+  
+  return 0;
+}
+
